@@ -14,14 +14,14 @@ formats supported by PIL).
 
 __project__ = 'pyBarcode'
 __author__ = 'Thorsten Weimann'
-__copyright__ = '2010-2011, ' + __author__
-__author_email__ = 'thorsten.weimann@gmx.net'
+__copyright__ = '2010-2013, ' + __author__
+__author_email__ = 'weimann@ymail.com'
 __description__ = ('Create standard barcodes with Python. No external '
                    'modules needed (optional PIL support included).')
-__version__ = '0.6'
-__release__ = '0.6'
+__version__ = '0.7'
+__release__ = '0.7'
 __license__ = 'MIT'
-__url__ = 'http://bitbucket.org/whitie/pybarcode/'
+__url__ = 'https://bitbucket.org/whitie/python-barcode/'
 __classifiers__ = [
     'Development Status :: 5 - Production/Stable',
     'Environment :: Console',
@@ -40,6 +40,11 @@ from barcode.ean import EAN8, EAN13, JAN
 from barcode.isxn import ISBN10, ISBN13, ISSN
 from barcode.upc import UPCA
 
+try:
+    _strbase = basestring  # lint:ok
+except NameError:
+    _strbase = str
+
 
 __BARCODE_MAP = dict(
     ean8=EAN8,
@@ -58,11 +63,11 @@ __BARCODE_MAP = dict(
     pzn=PZN,
 )
 
-PROVIDED_BARCODES = __BARCODE_MAP.keys()
+PROVIDED_BARCODES = list(__BARCODE_MAP.keys())
 PROVIDED_BARCODES.sort()
 
 
-def get_barcode(name, code=None, writer=None):
+def get(name, code=None, writer=None):
     try:
         barcode = __BARCODE_MAP[name.lower()]
     except KeyError:
@@ -74,16 +79,19 @@ def get_barcode(name, code=None, writer=None):
         return barcode
 
 
-def get_barcode_class(name):
+def get_class(name):
     return get_barcode(name)
 
 
 def generate(name, code, writer=None, output=None, writer_options=None):
     options = writer_options or {}
     barcode = get_barcode(name, code, writer)
-    if isinstance(output, basestring):
+    if isinstance(output, _strbase):
         fullname = barcode.save(output, options)
         return fullname
     else:
         barcode.write(output, options)
 
+
+get_barcode = get
+get_barcode_class = get_class
