@@ -37,6 +37,10 @@ class Barcode(object):
             code[i] = line.replace('1', 'X').replace('0', ' ')
         return '\n'.join(code)
 
+    def __repr__(self):
+        return '<{0}({1!r})>'.format(self.__class__.__name__,
+                                     self.get_fullcode())
+
     def build(self):
         raise NotImplementedError
 
