@@ -69,11 +69,11 @@ class InternationalStandardBookNumber10(InternationalStandardBookNumber13):
         isbn = isbn[:self.digits]
         self.isbn10 = isbn
         self.isbn10 = '{0}{1}'.format(isbn, self._calculate_checksum())
-        InternationalStandardBookNumber13.__init__(self, '978'+isbn, writer)
+        InternationalStandardBookNumber13.__init__(self, '978' + isbn, writer)
 
     def _calculate_checksum(self):
-        tmp = sum([x*int(y) for x, y in enumerate(self.isbn10[:9],
-                                                  start=1)]) % 11
+        tmp = sum([x * int(y) for x, y in enumerate(self.isbn10[:9],
+                                                    start=1)]) % 11
         if tmp == 10:
             return 'X'
         else:
@@ -82,6 +82,8 @@ class InternationalStandardBookNumber10(InternationalStandardBookNumber13):
     def __unicode__(self):
         return self.isbn10
 
+    __str__ = __unicode__
+
 
 class InternationalStandardSerialNumber(EuropeanArticleNumber13):
     """Initializes new ISSN barcode. This code is rendered as EAN-13
@@ -106,8 +108,8 @@ class InternationalStandardSerialNumber(EuropeanArticleNumber13):
         EuropeanArticleNumber13.__init__(self, self.make_ean(), writer)
 
     def _calculate_checksum(self):
-        tmp = 11 - sum([x*int(y) for x, y in enumerate(reversed(self.issn[:7]),
-                                                       start=2)]) % 11
+        tmp = 11 - sum([x * int(y) for x, y in
+                        enumerate(reversed(self.issn[:7]), start=2)]) % 11
         if tmp == 10:
             return 'X'
         else:
@@ -119,6 +121,8 @@ class InternationalStandardSerialNumber(EuropeanArticleNumber13):
     def __unicode__(self):
         return self.issn
 
+    __str__ = __unicode__
+
 
 # Shortcuts
 ISBN13 = InternationalStandardBookNumber13
